@@ -3,6 +3,9 @@ import json
 import logging
 from six.moves.urllib.parse import urlencode
 import requests
+from oauthlib.oauth1 import SIGNATURE_RSA
+from requests_oauthlib import OAuth1
+
 
 log = logging.getLogger(__name__)
 
@@ -14,8 +17,7 @@ class AtlassianRestAPI(object):
     form_token_headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
                           'X-Atlassian-Token': 'no-check'}
 
-    def __init__(self, url, username, password, timeout=60, api_root='rest/api', api_version='latest', verify_ssl=True,
-                 session=None):
+    def __init__(self, url, username=None, password=None, timeout=60, api_root='rest/api', api_version='latest', verify_ssl=True, session=None, oauth=None):
         self.url = url
         self.username = username
         self.password = password
@@ -28,7 +30,19 @@ class AtlassianRestAPI(object):
         else:
             self._session = session
         if username and password:
-            self._session.auth = (username, password)
+            self._create_basic_session(username, password)
+        elif oauth is not None:
+            self._create_oauth_session(oauth, timeout)
+
+    def _create_basic_session(self, username, password):
+        self._session.auth = (username, password)
+
+    def _create_oauth_session(self, oauth_dict, timeout=60):
+        oauth = OAuth1(oauth_dict['consumer_key'],
+                       rsa_key=oauth_dict['key_cert'], signature_method=SIGNATURE_RSA,
+                       resource_owner_key=oauth_dict['access_token'],
+                       resource_owner_secret=oauth_dict['access_token_secret'])
+        self._session.auth = oauth
 
     def log_curl_debug(self, method, path, data=None, headers=None, trailing=None, level=logging.DEBUG):
         """
@@ -42,9 +56,8 @@ class AtlassianRestAPI(object):
         :return:
         """
         headers = headers or self.default_headers
-        message = "curl --silent -X {method} -u '{username}':'********' -H {headers} {data} '{url}'".format(
+        message = "curl --silent -X {method} -H {headers} {data} '{url}'".format(
             method=method,
-            username=self.username,
             headers=' -H '.join(["'{0}: {1}'".format(key, value) for key, value in headers.items()]),
             data='' if not data else "--data '{0}'".format(json.dumps(data)),
             url='{0}'.format(self.url_joiner(self.url, path=path, trailing=trailing)))
@@ -91,7 +104,6 @@ class AtlassianRestAPI(object):
             url=url,
             headers=headers,
             data=data,
-            auth=(self.username, self.password),
             timeout=self.timeout,
             verify=self.verify_ssl,
             files=files
@@ -109,10 +121,18 @@ class AtlassianRestAPI(object):
             log.debug('Received: {0}\n "Created" response'.format(response.status_code))
         elif response.status_code == 204:
             log.debug('Received: {0}\n "No Content" response'.format(response.status_code))
+        elif response.status_code == 400:
+            log.error('Received: {0}\n Bad request \n'.format(response.status_code, response_content))
         elif response.status_code == 401:
             log.error('Received: {0}\n "UNAUTHORIZED" response'.format(response.status_code))
         elif response.status_code == 404:
             log.error('Received: {0}\n Not Found'.format(response.status_code))
+        elif response.status_code == 403:
+            log.error('Received: {0}\n Forbidden. Please, check permissions'.format(response.status_code))
+        elif response.status_code == 409:
+            log.error('Received: {0}\n Conflict \n '.format(response.status_code, response_content))
+        elif response.status_code == 413:
+            log.error('Received: {0}\n Request entity too large'.format(response.status_code))
         else:
             log.debug('Received: {0}\n {1}'.format(response.status_code, response))
             self.log_curl_debug(method=method, path=path, headers=headers, data=data, level=logging.DEBUG)
@@ -133,6 +153,7 @@ class AtlassianRestAPI(object):
         :param params:
         :param headers:
         :param not_json_response: OPTIONAL: For get content from raw requests packet
+        :param trailing: OPTIONAL: for wrap slash symbol in the end of string
         :return:
         """
         answer = self.request('GET', path=path, flags=flags, params=params, data=data, headers=headers,
